==> mesa_19.0.8.orig.tar.gz: mesa-19.0.8/src/amd/vulkan/radv_shader_helper.h <==
/*
 * Copyright © 2018 Red Hat.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */
#ifndef RADV_SHADER_HELPER_H
#define RADV_SHADER_HELPER_H
#ifdef __cplusplus
extern "C" {
#endif

bool radv_init_llvm_compiler(struct ac_llvm_compiler *info,
			     bool thread_compiler,
			     enum radeon_family family,
			     enum ac_target_machine_options tm_options);
void radv_destroy_llvm_compiler(struct ac_llvm_compiler *info,
				bool thread_compiler);

bool radv_compile_to_binary(struct ac_llvm_compiler *info,
			    LLVMModuleRef module,
			    struct ac_shader_binary *binary);

#ifdef __cplusplus
}
#endif
#endif

==> mesa_20.3.5.orig.tar.gz: mesa-20.3.5/src/amd/vulkan/radv_shader_helper.h <==
/*
 * Copyright © 2018 Red Hat.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */
#ifndef RADV_SHADER_HELPER_H
#define RADV_SHADER_HELPER_H
#ifdef __cplusplus
extern "C" {
#endif

bool radv_init_llvm_compiler(struct ac_llvm_compiler *info,
			     bool thread_compiler,
			     enum radeon_family family,
			     enum ac_target_machine_options tm_options,
			     unsigned wave_size);
void radv_destroy_llvm_compiler(struct ac_llvm_compiler *info,
				bool thread_compiler);

bool radv_compile_to_elf(struct ac_llvm_compiler *info,
			 LLVMModuleRef module,
			 char **pelf_buffer, size_t *pelf_size);

#ifdef __cplusplus
}
#endif
#endif
